@@ -124,13 +124,9 @@ sn <- function(x) {
 #' @export
 extendMatrix <- function(mtx, col.names) {
   new.names <- setdiff(col.names, colnames(mtx))
-  ## if all col.names already included in matrix, don't extend
-  if (identical(new.names, character(0))){
-    return(mtx)
-  }
   ext.mtx <- matrix(0, nrow=nrow(mtx), ncol=length(new.names))
   colnames(ext.mtx) <- new.names
-  return(cbind(mtx, ext.mtx)[, col.names])
+  return(cbind(mtx, ext.mtx)[,col.names])
 }
 
 #' Merge list of count matrices into a common matrix, entering 0s for the missing entries
